# Baam

[![PyPI version](https://badge.fury.io/py/baam.svg)](https://badge.fury.io/py/baam)
[![Unstable package](https://img.shields.io/badge/_Unstable_package_-_This_code_is_a_work_in_progress_-red)](https://semver.org)

Build and ship apps with one command.


## Inspired by

> "Bang, baam, thank you ma'am."
>
> — Dean Martin
